@@ -1,6 +1,6 @@
 /* io_commands.c
  *
- * $Id: io_commands.c,v 1.32 2000/04/21 22:29:39 nisse Exp $
+ * $Id: io_commands.c,v 1.33 2000/05/06 11:17:34 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -205,8 +205,8 @@ do_listen(struct io_backend *backend,
 /* A listen function taking three arguments:
  * (listen callback backend port).
  *
- * Suitable for handling forwarding requests.
- * NOTE: The calling function has to do all remembering of the fd:s. */
+ * Suitable for handling forwarding requests. NOTE: The calling
+ * function has to do all remembering of the fd:s. */
 
 /* GABA:
    (class
@@ -228,7 +228,7 @@ do_listen_with_callback(struct command *s,
 
   /* No dns lookups */
   do_listen(self->backend, address, 0,
-	    NULL, /* FIXME: resources */
+	    NULL,
 	    c,
 	    make_apply(self->callback,
 		       &discard_continuation, e), e);
