@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: publickey_crypto.h,v 1.38 2000/06/04 19:43:48 nisse Exp $ */
+ * $Id: publickey_crypto.h,v 1.39 2000/06/10 13:06:15 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -89,6 +89,9 @@ void init_dsa_public(struct dsa_public *public);
 int parse_dsa_public(struct simple_buffer *buffer,
 		     struct dsa_public *public);
 
+struct sexp *
+make_dsa_public_key(struct dsa_public *dsa);
+
 struct signature_algorithm *make_dsa_algorithm(struct randomness *random);
 
 /* Non spki keys */
